[![PyPI](https://img.shields.io/pypi/v/komet.svg?style=for-the-badge)](https://pypi.org/project/komet/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/komet.svg?style=for-the-badge)](https://pypi.org/project/komet/)
[![license](https://img.shields.io/github/license/aerosadegh/komet.svg?style=for-the-badge)](https://github.com/aerosadegh/komet/blob/main/LICENSE)
[![GitHub stars](https://img.shields.io/github/stars/aerosadegh/komet.svg?style=for-the-badge&label=Stars)](https://github.com/aerosadegh/komet)

# Komet

A simple class for print python objects with tails.
